#' Redo all map plots of a rds file
#'
#' Redo all map plots of a rds file. Displaying map plots in the browser can lead
#' to problems when the rds file was made with an older version of R and is viewed
#' with a newer version. Running this function on a rds file using the newer version
#' of R should fix the problem.
#'
#' @param rds_file an existing rds file
#' @param dslist named list of elists containing logFC data
#' @param ci_list named list of ci diffs
#' @param grid grid
#' @param nodeframe universe nodeframe
#' @param type character string 'treatment' or 'recovery
#' @param filename path and filename
#'
#' @return
#' @export
redo_maplots = function(rds_file,
                        dslist,
                        ci_list,
                        grid,
                        nodeframe,
                        type = c('treatment', 'recovery'),
                        filename) {
    plot_list = toxprofileR::create_shiny_plotlist(dslist, ci_list, grid, nodeframe, type)

    rds_file$targets_all = plot_list$targets_all
    rds_file$plotlist = plot_list$plotlist
    rds_file$maplegend = plot_list$maplegend
    rds_file$session_info = sessionInfo()

    saveRDS(rds_file, file = filename)
    message(paste("Shiny data stored as", filename))
}
